==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_entities/customerrental_001/IssueDetails.java <==

package net.datastream.schemas.mp_entities.customerrental_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.LOCATIONID_Type;
import net.datastream.schemas.mp_fields.UOMID_Type;
import net.datastream.schemas.mp_fields.USERID_Type;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISSUEDDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ESTIMATEDISSUEDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISSUEREADING" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UOMID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISSUELOCATION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISSUEVEFUELLEVEL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISSUEDBY" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "issueddate",
    "estimatedissuedate",
    "issuereading",
    "uomid",
    "issuelocation",
    "issuevefuellevel",
    "issuedby"
})
@XmlRootElement(name = "IssueDetails")
public class IssueDetails {

    @XmlElement(name = "ISSUEDDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME issueddate;
    @XmlElement(name = "ESTIMATEDISSUEDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME estimatedissuedate;
    @XmlElement(name = "ISSUEREADING", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY issuereading;
    @XmlElement(name = "UOMID", namespace = "http://schemas.datastream.net/MP_fields")
    protected UOMID_Type uomid;
    @XmlElement(name = "ISSUELOCATION", namespace = "http://schemas.datastream.net/MP_fields")
    protected LOCATIONID_Type issuelocation;
    @XmlElement(name = "ISSUEVEFUELLEVEL", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY issuevefuellevel;
    @XmlElement(name = "ISSUEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type issuedby;

    /**
     * Gets the value of the issueddate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getISSUEDDATE() {
        return issueddate;
    }

    /**
     * Sets the value of the issueddate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setISSUEDDATE(DATETIME value) {
        this.issueddate = value;
    }

    /**
     * Gets the value of the estimatedissuedate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getESTIMATEDISSUEDATE() {
        return estimatedissuedate;
    }

    /**
     * Sets the value of the estimatedissuedate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setESTIMATEDISSUEDATE(DATETIME value) {
        this.estimatedissuedate = value;
    }

    /**
     * Gets the value of the issuereading property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getISSUEREADING() {
        return issuereading;
    }

    /**
     * Sets the value of the issuereading property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setISSUEREADING(QUANTITY value) {
        this.issuereading = value;
    }

    /**
     * Gets the value of the uomid property.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getUOMID() {
        return uomid;
    }

    /**
     * Sets the value of the uomid property.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setUOMID(UOMID_Type value) {
        this.uomid = value;
    }

    /**
     * Gets the value of the issuelocation property.
     * 
     * @return
     *     possible object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public LOCATIONID_Type getISSUELOCATION() {
        return issuelocation;
    }

    /**
     * Sets the value of the issuelocation property.
     * 
     * @param value
     *     allowed object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public void setISSUELOCATION(LOCATIONID_Type value) {
        this.issuelocation = value;
    }

    /**
     * Gets the value of the issuevefuellevel property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getISSUEVEFUELLEVEL() {
        return issuevefuellevel;
    }

    /**
     * Sets the value of the issuevefuellevel property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setISSUEVEFUELLEVEL(QUANTITY value) {
        this.issuevefuellevel = value;
    }

    /**
     * Gets the value of the issuedby property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getISSUEDBY() {
        return issuedby;
    }

    /**
     * Sets the value of the issuedby property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setISSUEDBY(USERID_Type value) {
        this.issuedby = value;
    }

}

==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_entities/customerrental_001/IssueDetails.java <==

package net.datastream.schemas.mp_entities.customerrental_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.LOCATIONID_Type;
import net.datastream.schemas.mp_fields.UOMID_Type;
import net.datastream.schemas.mp_fields.USERID_Type;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ISSUEDDATE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ESTIMATEDISSUEDATE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ISSUEREADING" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}UOMID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ISSUELOCATION" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ISSUEVEFUELLEVEL" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ISSUEDBY" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "issueddate",
    "estimatedissuedate",
    "issuereading",
    "uomid",
    "issuelocation",
    "issuevefuellevel",
    "issuedby"
})
@XmlRootElement(name = "IssueDetails")
public class IssueDetails {

    @XmlElement(name = "ISSUEDDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME issueddate;
    @XmlElement(name = "ESTIMATEDISSUEDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME estimatedissuedate;
    @XmlElement(name = "ISSUEREADING", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY issuereading;
    @XmlElement(name = "UOMID", namespace = "http://schemas.datastream.net/MP_fields")
    protected UOMID_Type uomid;
    @XmlElement(name = "ISSUELOCATION", namespace = "http://schemas.datastream.net/MP_fields")
    protected LOCATIONID_Type issuelocation;
    @XmlElement(name = "ISSUEVEFUELLEVEL", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY issuevefuellevel;
    @XmlElement(name = "ISSUEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type issuedby;

    /**
     * Gets the value of the issueddate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getISSUEDDATE() {
        return issueddate;
    }

    /**
     * Sets the value of the issueddate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setISSUEDDATE(DATETIME value) {
        this.issueddate = value;
    }

    /**
     * Gets the value of the estimatedissuedate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getESTIMATEDISSUEDATE() {
        return estimatedissuedate;
    }

    /**
     * Sets the value of the estimatedissuedate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setESTIMATEDISSUEDATE(DATETIME value) {
        this.estimatedissuedate = value;
    }

    /**
     * Gets the value of the issuereading property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getISSUEREADING() {
        return issuereading;
    }

    /**
     * Sets the value of the issuereading property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setISSUEREADING(QUANTITY value) {
        this.issuereading = value;
    }

    /**
     * Gets the value of the uomid property.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getUOMID() {
        return uomid;
    }

    /**
     * Sets the value of the uomid property.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setUOMID(UOMID_Type value) {
        this.uomid = value;
    }

    /**
     * Gets the value of the issuelocation property.
     * 
     * @return
     *     possible object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public LOCATIONID_Type getISSUELOCATION() {
        return issuelocation;
    }

    /**
     * Sets the value of the issuelocation property.
     * 
     * @param value
     *     allowed object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public void setISSUELOCATION(LOCATIONID_Type value) {
        this.issuelocation = value;
    }

    /**
     * Gets the value of the issuevefuellevel property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getISSUEVEFUELLEVEL() {
        return issuevefuellevel;
    }

    /**
     * Sets the value of the issuevefuellevel property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setISSUEVEFUELLEVEL(QUANTITY value) {
        this.issuevefuellevel = value;
    }

    /**
     * Gets the value of the issuedby property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getISSUEDBY() {
        return issuedby;
    }

    /**
     * Sets the value of the issuedby property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setISSUEDBY(USERID_Type value) {
        this.issuedby = value;
    }

}
